@@ -62,7 +62,7 @@ use strict;
 use warnings;
 use Fcntl;
 
-our $VERSION = '1.11.0'; # VERSION
+our $VERSION = '1.12.0'; # VERSION
 
 require Rex::Exporter;
 use Data::Dumper;
@@ -71,6 +71,7 @@ use Rex::FS::File;
 use Rex::Commands::Upload;
 use Rex::Commands::MD5;
 use Rex::File::Parser::Data;
+use Rex::Helper::File::Spec;
 use Rex::Helper::System;
 use Rex::Helper::Path;
 use Rex::Hook;
@@ -475,13 +476,7 @@ sub file {
     # first upload file to tmp location, to get md5 sum.
     # than we can decide if we need to replace the current (old) file.
 
-    my @splitted_file = split( /[\/\\]/, $file );
-    my $file_name     = ".rex.tmp." . pop(@splitted_file);
-    my $tmp_file_name = (
-      $#splitted_file != -1
-      ? ( join( "/", @splitted_file ) . "/" . $file_name )
-      : $file_name
-    );
+    my $tmp_file_name = get_tmp_file_name($file);
 
     my $fh    = file_write($tmp_file_name);
     my @lines = split( qr{$/}, $option->{"content"} );
@@ -752,6 +747,20 @@ sub file {
   return $__ret->{changed};
 }
 
+sub get_tmp_file_name {
+  my $file = shift;
+
+  my $dirname  = dirname($file);
+  my $filename = ".rex.tmp." . basename($file);
+
+  my $tmp_file_name =
+      $dirname eq '.'
+    ? $filename
+    : Rex::Helper::File::Spec->catfile( $dirname, $filename );
+
+  return $tmp_file_name;
+}
+
 =head2 file_write($file_name)
 
 This function opens a file for writing (it will truncate the file if it already exists). It returns a Rex::FS::File object on success.
